#
# Example usage of pyl3dgecomm v0.1
#
# Copyright (c) 2010-2012 Centre for Advanced Internet Architectures,
# Swinburne University of Technology.
#
# Authors:    Grenville Armitage  (garmitage@swin.edu.au)
#            Chris Holman        (6963420@student.swin.edu.au)
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.



# Optional set path if you have installed the module in a non-standard location
#import sys
#sys.path.append("c:\\python32\\dlls")

import pyl3dgecomm
import random
import time

# Available metrics are:
# METRIC_SPIN 
# METRIC_BOUNCE_HEIGHT 
# METRIC_SCALE 
# METRIC_ROLL 
# METRIC_COLOR 
# METRIC_BOUNCE_RATE  
# METRIC_SOUND 
# METRIC_ALT_SKIN 
# METRIC_ALT_MODEL 
# METRIC_UNUSED 
# METRIC_INFO 

# Available fields are:
# FIELD_RATE   The numerical value the program uses to apply the modifier (eg "20")
# FIELD_VALUE  The human readable value disiplayed when the object is queried (eg "20k PPS")
# FIELD_NAME   The human readable name of the field (eg "Network traffic, inbound")

entity_one = 1
server_ip = "127.0.0.1"
server_port = "27960"
local_ip = "" # blank for any/all local IPs

# Initiate l3dgecomms connection
conn = pyl3dgecomm.l3dgecomm(server_ip, server_port, local_ip, accept_actions=True)

# Set the field name of a metric
conn.sendEntityUpdate(0, pyl3dgecomm.METRIC_SPIN,pyl3dgecomm.FIELD_NAME, "Temperature")

# Send a single entity update, setting entity one to spin at rate randint(0,100)
conn.sendEntityUpdate(entity_one,pyl3dgecomm.METRIC_SPIN,pyl3dgecomm.FIELD_RATE, str(random.randint(0,100))) #entityid,metric,field,value):
conn.sendEntityUpdate(entity_one,pyl3dgecomm.METRIC_SPIN,pyl3dgecomm.FIELD_VALUE, str(random.randint(0,100)) + " Degrees C" )

# Trigger the server to reread the position of entity one from its config files
conn.triggerEntityCoordUpdate(entity_one)

# Trigger the server to reread the position of entities two,three,four and five
# from its config files
conn.triggerMultiEntityCoordUpdate([2,3,4,5])

# You must call checkIncoming() even if you're not expecting actions, as it will 
# check for invalid tokens and such. 
while 1:
  action = conn.checkIncoming() 
  while action != False:
    
    print (action[0] + " " + action[1] + " " + action[2])
    action = conn.checkIncoming()
  time.sleep(0.1)
  